@@ -6,7 +6,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-07-06'; # DATE
 our $DIST = 'Acme-CPANModules-PERLANCAR-Unused'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 my $unused_dists = <<'_';
 Acme-PERLANCAR-Dummy
@@ -55,16 +55,16 @@ Acme::CPANModules::PERLANCAR::Unused - List of my modules which are (currently n
 
 =head1 VERSION
 
-This document describes version 0.002 of Acme::CPANModules::PERLANCAR::Unused (from Perl distribution Acme-CPANModules-PERLANCAR-Unused), released on 2023-07-06.
+This document describes version 0.003 of Acme::CPANModules::PERLANCAR::Unused (from Perl distribution Acme-CPANModules-PERLANCAR-Unused), released on 2023-07-06.
 
 =head1 DESCRIPTION
 
-I use this to generate L<Task::PERLANCAR::Used>, which in turn I use to install
-all my perl modules on a new perl installation. What I usually do after
+I use this to generate L<Task::BeLike::PERLANCAR::Used>, which in turn I use to
+install all my perl modules on a new perl installation. What I usually do after
 installing a perl with L<perlbrew>:
 
  % cpanm -n App::cpanm::perlancar
- % cpanm-perlancar -n Task::PERLANCAR::Used
+ % cpanm-perlancar -n Task::BeLike::PERLANCAR::Used
 
 =head1 ACME::CPANMODULES ENTRIES
 
@@ -185,7 +185,7 @@ Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModules-PER
 
 =head1 SEE ALSO
 
-L<Task::PERLANCAR::Used>
+L<Task::BeLike::PERLANCAR::Used>
 
 L<Acme::CPANModules> - about the Acme::CPANModules namespace
 
